@@ -18,6 +18,37 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. *
  */
 
+/*
+ * Documentation marked with DHS is my fault.
+ *               -- David H. Silber <pilot@SilberSoft.com>
+ */
+
+/***********************************************************************
+ *  The functions in this file use the Desktop Link Protocol to interact
+ *  with a connected Palm device.
+ *
+ *  The first section of this file contains utility functions.
+ *
+ *  Functions useful to people writing conduits are at the end.  (Search
+ *  for '<Conduit>'.)
+ *
+ *  -- DHS
+ ***********************************************************************/
+
+
+/***********************************************************************
+ *  Key to documentation
+ *
+ *  Parameters marked with '-->' are data passed in to the function.
+ *  Parameters marked with '<--' are data passed back from the function.
+ *    If the argument is a NULL, no data is returned.
+ *  Parameters marked with '<->' are used for data passed in and then
+ *    (possibly modified) data passed back.
+ *
+ *  -- DHS
+ ***********************************************************************/
+
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -505,6 +536,14 @@ static void dlp_htopdate(time_t time, unsigned char *data)
 	return;
 }
 
+
+/***********************************************************************
+ *  Functions for use by conduit programmers start here.   <Conduit>
+ *
+ *  -- DHS
+ ***********************************************************************/
+
+
 /***********************************************************************
  *
  * Function:    dlp_GetSysDateTime
@@ -886,7 +925,7 @@ int dlp_OpenDB(int sd, int cardno, int mode, char *name, int *dbhandle)
 		*dbhandle = get_byte(DLP_RESPONSE_DATA(res, 0, 0));
 
 		LOG((PI_DBG_DLP, PI_DBG_LVL_INFO,
-		    "DLP OpenDB Handle=%d", *dbhandle));
+		    "DLP OpenDB Handle=%d\n", *dbhandle));
 	}
 	
 	dlp_response_free(res);
@@ -966,7 +1005,7 @@ dlp_CreateDB(int sd, long creator, long type, int cardno, int flags,
 		*dbhandle = get_byte(DLP_RESPONSE_DATA(res, 0, 0));
 
 		LOG((PI_DBG_DLP, PI_DBG_LVL_INFO,
-		    "DLP CreateDB Handle=%d", *dbhandle));
+		    "DLP CreateDB Handle=%d\n", *dbhandle));
 	}
 	
 	dlp_response_free(res);
@@ -1792,6 +1831,8 @@ dlp_GetROMToken(int sd, unsigned long token, char *buffer, unsigned int *size)
 	int val;
 	unsigned long buffer_ptr;
 
+	Trace(GetROMToken);
+	
 #ifdef DLP_TRACE
 	if (dlp_trace) {
 	  fprintf(stderr,
@@ -2015,29 +2056,7 @@ dlp_WriteRecord(int sd, int dbhandle, int flags, recordid_t recID,
 
 	memcpy(DLP_REQUEST_DATA(req, 0, 8), data, length);
 
-#ifdef DLP_TRACE
-	if (dlp_trace) {
-		fprintf(stderr,
-			" Wrote: Handle: %d, RecordID: 0x%8.8lX, Category: %d\n",
-			dbhandle, (unsigned long) recID, catID);
-		fprintf(stderr, "        Flags:");
-		if (flags & dlpRecAttrDeleted)
-			fprintf(stderr, " Deleted");
-		if (flags & dlpRecAttrDirty)
-			fprintf(stderr, " Dirty");
-		if (flags & dlpRecAttrBusy)
-			fprintf(stderr, " Busy");
-		if (flags & dlpRecAttrSecret)
-			fprintf(stderr, " Secret");
-		if (flags & dlpRecAttrArchived)
-			fprintf(stderr, " Archive");
-		if (!flags)
-			fprintf(stderr, " None");
-		fprintf(stderr, " (0x%2.2X), and %d bytes of data: \n",
-			flags, length);
-		dumpdata(data, length);
-	}
-#endif
+	CHECK(PI_DBG_DLP, PI_DBG_LVL_DEBUG, record_dump(DLP_RESPONSE_DATA(req, 0, 0)));
 	
 	result = dlp_exec(sd, req, &res);
 
@@ -2914,11 +2933,21 @@ dlp_WriteAppPreference(int sd, unsigned long creator, int id, int backup,
  * Summary:     Iterate through modified records in category, returning 
  *		subsequent modifieded records on each call
  *
- * Parameters:  None
+ * Parameters:  sd         --> Socket descriptor as returned by
+ *                             pilot_connect().
+ *              fHandle    --> Database handle as returned by dlp_OpenDB().
+ *              incategory --> Category to fetch records from.
+ *              buffer     <-- Data from specified record.
+ *              id         <-- Record ID of record on palm device.
+ *              index      <-- Specifies record to get.
+ *              size       <-- Size of data returned in buffer.
+ *              attr       <-- Attributes from record on palm device.
  *
  * Returns:     A negative number on error, the number of bytes read
  *		otherwise
  *
+ * Parameter documentation by DHS.
+ *
  ***********************************************************************/
 int
 dlp_ReadNextModifiedRecInCategory(int sd, int fHandle, int incategory,
@@ -3119,11 +3148,23 @@ dlp_ReadRecordById(int sd, int fHandle, recordid_t id, void *buffer,
  *
  * Summary:     Searches device database for match on a record by index
  *
- * Parameters:  None
+ * Parameters:  sd       --> Socket descriptor as returned by pilot_connect().
+ *              fHandle  --> Database handle as returned by dlp_OpenDB().
+ *              index    --> Specifies record to get.
+ *              buffer   <-- Data from specified record.
+ *              id       <-- Record ID of record on palm device.
+ *              size     <-- Size of data returned in buffer.
+ *              attr     <-- Attributes from record on palm device.
+ *              category <-- Category from record on palm device.
  *
  * Returns:     A negative number on error, the number of bytes read
  *		otherwise
  *
+ * Turns this request for a particular record in the database into a
+ * low-level dlp request.
+ *
+ * Parameter documentation by DHS.
+ *
  ***********************************************************************/
 int
 dlp_ReadRecordByIndex(int sd, int fHandle, int index, void *buffer,
