@@ -1242,7 +1242,7 @@ int pi_file_retrieve(struct pi_file *pf, int socket, int cardno)
 			display_rate(j + 1, l, written,
 				     (int) ((unsigned long) time(NULL) -
 					    start_time));
-			 */
+			*/
 
 			if ((dlp_ReadResourceByIndex
 			     (socket, db, j, buffer, &type, &id,
@@ -1273,6 +1273,7 @@ int pi_file_retrieve(struct pi_file *pf, int socket, int cardno)
 				     (int) ((unsigned long) time(NULL) -
 					    start_time));
 			*/
+
 			/* There is no way to restore records with these
 			   attributes, so there is no use in backing them up
 			 */
@@ -1285,7 +1286,6 @@ int pi_file_retrieve(struct pi_file *pf, int socket, int cardno)
 				return -1;
 			}
 		}
-	/* printf("\n"); */
 	return dlp_CloseDB(socket, db);
 }
 
@@ -1314,7 +1314,7 @@ int pi_file_install(struct pi_file *pf, int socket, int cardno)
 	void 	*buffer;
 
 	version = pi_version(socket);
-//	printf("\n");
+	/* printf("\n"); */
 
 	/* Delete DB if it already exists */
 	dlp_DeleteDB(socket, cardno, pf->info.name);
@@ -1493,7 +1493,7 @@ int pi_file_install(struct pi_file *pf, int socket, int cardno)
 					       start_time));
 			*/
 		}
-//		printf("\n");
+		printf("\n");
 	}
 
 	if (reset)
