@@ -16,7 +16,7 @@
 
 #line 1 "parsedate.y"
 
-/* $Revision: 1.22 $
+/* $Revision: 1.23 $
 **
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
 **  at the University of North Carolina at Chapel Hill.  Later tweaked by
@@ -1781,7 +1781,7 @@ main(ac, av)
 	    (void)printf("%s", ctime(&d));
     }
 
-    exit(0);
+    return 0;
     /* NOTREACHED */
 }
 #endif /* TEST */
